import React, { useState } from "react";
import "./spacemanager.css";

interface SpaceManagerProps {
    spaceId: string;
    onDeleteSpace: (spaceId: string) => void;
    onRenameSpace: (newId: string) => void;
    onDuplicateSpace: (newId: string) => void;
    onCreateSpace: (spaceId: string) => void;
}

function SpaceManager({
    spaceId,
    onDeleteSpace,
    onRenameSpace,
    onDuplicateSpace,
    onCreateSpace,
}: SpaceManagerProps) {
    const [deleteConfirmationVisible, setDeleteConfirmationVisible] =
        useState(false);
    const [newSpaceName, setNewSpaceName] = useState("New graph");

    const handleDeleteSpace = () => {
        setDeleteConfirmationVisible(false);
        onDeleteSpace(spaceId);
    };

    return (
        <div id="space-manager">
            <label htmlFor="space-name">New graph name</label>
            <br />
            <input
                id="space-name"
                type={"text"}
                value={newSpaceName}
                onChange={(e) => setNewSpaceName(e.target.value)}
            />

            <ul>
                <li>
                    <button
                        disabled={newSpaceName.length === 0}
                        onClick={() => onRenameSpace(newSpaceName)}
                    >
                        Rename to {'"' + newSpaceName + '"'}
                    </button>
                </li>
                <li>
                    <button
                        disabled={newSpaceName.length === 0}
                        onClick={() => onDuplicateSpace(newSpaceName)}
                    >
                        Duplicate as {'"' + newSpaceName + '"'}
                    </button>
                </li>
                <li>
                    <button
                        disabled={newSpaceName.length === 0}
                        onClick={() => onCreateSpace(newSpaceName)}
                    >
                        Create empty graph {'"' + newSpaceName + '"'}
                    </button>
                </li>
            </ul>
            <hr />
            <ul>
                <li>
                    <button
                        onClick={() =>
                            setDeleteConfirmationVisible(
                                !deleteConfirmationVisible
                            )
                        }
                    >
                        Delete graph {'"' + spaceId + '"'}?
                    </button>
                </li>
                {deleteConfirmationVisible && (
                    <li>
                        <button className="warning" onClick={handleDeleteSpace}>
                            Delete the graph {'"' + spaceId + '"'} and all its
                            data
                        </button>
                    </li>
                )}
            </ul>
        </div>
    );
}

export default SpaceManager;
